@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 import sys
+import warnings
 
 from django.conf import settings
 from django.core.management import execute_from_command_line
 
-
 if not settings.configured:
     settings.configure(
         DATABASES={
@@ -21,6 +21,10 @@ if not settings.configured:
     )
 
 
+warnings.simplefilter('default', DeprecationWarning)
+warnings.simplefilter('default', PendingDeprecationWarning)
+
+
 def runtests():
     argv = sys.argv[:1] + ['test'] + sys.argv[1:]
     execute_from_command_line(argv)
