@@ -10,20 +10,22 @@ from taggit.models import (CommonGenericTaggedItemBase, GenericTaggedItemBase,
 
 # Ensure that two TaggableManagers with custom through model are allowed.
 class Through1(TaggedItemBase):
-    content_object = models.ForeignKey('MultipleTags')
+    content_object = models.ForeignKey('MultipleTags', on_delete=models.CASCADE)
 
 
 class Through2(TaggedItemBase):
-    content_object = models.ForeignKey('MultipleTags')
+    content_object = models.ForeignKey('MultipleTags', on_delete=models.CASCADE)
 
 
 class MultipleTags(models.Model):
     tags1 = TaggableManager(through=Through1, related_name='tags1')
     tags2 = TaggableManager(through=Through2, related_name='tags2')
 
+
 # Ensure that two TaggableManagers with GFK via different through models are allowed.
 class ThroughGFK(GenericTaggedItemBase):
-    tag = models.ForeignKey(Tag, related_name='tagged_items')
+    tag = models.ForeignKey(Tag, related_name='tagged_items', on_delete=models.CASCADE)
+
 
 class MultipleTagsGFK(models.Model):
     tags1 = TaggableManager(related_name='tagsgfk1')
@@ -39,6 +41,7 @@ class Food(models.Model):
     def __str__(self):
         return self.name
 
+
 @python_2_unicode_compatible
 class Pet(models.Model):
     name = models.CharField(max_length=50)
@@ -56,11 +59,11 @@ class HousePet(Pet):
 # Test direct-tagging with custom through model
 
 class TaggedFood(TaggedItemBase):
-    content_object = models.ForeignKey('DirectFood')
+    content_object = models.ForeignKey('DirectFood', on_delete=models.CASCADE)
 
 
 class TaggedPet(TaggedItemBase):
-    content_object = models.ForeignKey('DirectPet')
+    content_object = models.ForeignKey('DirectPet', on_delete=models.CASCADE)
 
 
 @python_2_unicode_compatible
@@ -90,10 +93,12 @@ class DirectHousePet(DirectPet):
 # Test custom through model to model with custom PK
 
 class TaggedCustomPKFood(TaggedItemBase):
-    content_object = models.ForeignKey('DirectCustomPKFood')
+    content_object = models.ForeignKey('DirectCustomPKFood', on_delete=models.CASCADE)
+
 
 class TaggedCustomPKPet(TaggedItemBase):
-    content_object = models.ForeignKey('DirectCustomPKPet')
+    content_object = models.ForeignKey('DirectCustomPKPet', on_delete=models.CASCADE)
+
 
 @python_2_unicode_compatible
 class DirectCustomPKFood(models.Model):
@@ -104,6 +109,7 @@ class DirectCustomPKFood(models.Model):
     def __str__(self):
         return self.name
 
+
 @python_2_unicode_compatible
 class DirectCustomPKPet(models.Model):
     name = models.CharField(max_length=50, primary_key=True)
@@ -113,14 +119,16 @@ class DirectCustomPKPet(models.Model):
     def __str__(self):
         return self.name
 
+
 class DirectCustomPKHousePet(DirectCustomPKPet):
     trained = models.BooleanField(default=False)
 
-# Test custom through model to model with custom PK using GenericForeignKey
 
+# Test custom through model to model with custom PK using GenericForeignKey
 class TaggedCustomPK(CommonGenericTaggedItemBase, TaggedItemBase):
     object_id = models.CharField(max_length=50, verbose_name='Object id', db_index=True)
 
+
 @python_2_unicode_compatible
 class CustomPKFood(models.Model):
     name = models.CharField(max_length=50, primary_key=True)
@@ -130,6 +138,7 @@ class CustomPKFood(models.Model):
     def __str__(self):
         return self.name
 
+
 @python_2_unicode_compatible
 class CustomPKPet(models.Model):
     name = models.CharField(max_length=50, primary_key=True)
@@ -139,16 +148,20 @@ class CustomPKPet(models.Model):
     def __str__(self):
         return self.name
 
+
 class CustomPKHousePet(CustomPKPet):
     trained = models.BooleanField(default=False)
 
 # Test custom through model to a custom tag model
 
+
 class OfficialTag(TagBase):
     official = models.BooleanField(default=False)
 
+
 class OfficialThroughModel(GenericTaggedItemBase):
-    tag = models.ForeignKey(OfficialTag, related_name="tagged_items")
+    tag = models.ForeignKey(OfficialTag, related_name="tagged_items", on_delete=models.CASCADE)
+
 
 @python_2_unicode_compatible
 class OfficialFood(models.Model):
@@ -159,6 +172,7 @@ class OfficialFood(models.Model):
     def __str__(self):
         return self.name
 
+
 @python_2_unicode_compatible
 class OfficialPet(models.Model):
     name = models.CharField(max_length=50)
@@ -168,6 +182,7 @@ class OfficialPet(models.Model):
     def __str__(self):
         return self.name
 
+
 class OfficialHousePet(OfficialPet):
     trained = models.BooleanField(default=False)
 
@@ -178,9 +193,11 @@ class Media(models.Model):
     class Meta:
         abstract = True
 
+
 class Photo(Media):
     pass
 
+
 class Movie(Media):
     pass
 
